@@ -1,23 +1,13 @@
-/* This file is part of the KDE Project
-   Copyright (c) 2014 Marco Martin <mart@kde.org>
+/*
+    This file is part of the KDE Project
+    SPDX-FileCopyrightText: 2014 Marco Martin <mart@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kcmoduleqml_p.h"
 
+#include <kcmutils_debug.h>
 
 #include <QVBoxLayout>
 #include <QQuickWindow>
@@ -110,6 +100,7 @@ KCModuleQml::KCModuleQml(std::unique_ptr<KQuickAddons::ConfigModule> configModul
     });
 #endif
 
+    connect(this, &KCModule::defaultsIndicatorsVisibleChanged, d->configModule.get(), &KQuickAddons::ConfigModule::setDefaultsIndicatorsVisible);
     //KCModule takes ownership of the kabout data so we need to force a copy
     setAboutData(new KAboutData(*d->configModule->aboutData()));
     setFocusPolicy(Qt::StrongFocus);
@@ -138,7 +129,10 @@ KCModuleQml::KCModuleQml(std::unique_ptr<KQuickAddons::ConfigModule> configModul
     //Qt bug https://bugreports.qt.io/browse/QTBUG-70934
     component->setData(QByteArrayLiteral("import QtQuick 2.3\n"
         "import org.kde.kirigami 2.4 as Kirigami\n"
+        "import QtQuick.Window 2.2\n"
         "Kirigami.ApplicationItem{"
+            //force it to *never* try to resize itself
+            "width: Window.width;"
             //purely cosmetic space, those magic values are to align perfectly within Systemsettings
             "header: Item {height: Math.round(Kirigami.Units.gridUnit*0.25)}"
             "implicitWidth:pageStack.implicitWidth;"
@@ -156,7 +150,7 @@ KCModuleQml::KCModuleQml(std::unique_ptr<KQuickAddons::ConfigModule> configModul
 
     d->rootPlaceHolder = qobject_cast<QQuickItem *>(component->create());
     if (!d->rootPlaceHolder) {
-        qCritical() << component->errors();
+        qCCritical(KCMUTILS_LOG) << component->errors();
         qFatal("Failed to intiailize KCModuleQML");
     }
     d->quickWidget->setContent(QUrl(), component, d->rootPlaceHolder);
@@ -177,6 +171,10 @@ KCModuleQml::KCModuleQml(std::unique_ptr<KQuickAddons::ConfigModule> configModul
             d->pageRow->setProperty("currentIndex", d->configModule->currentIndex());
             }
         );
+        connect(d->configModule.get(), &KQuickAddons::ConfigModule::passiveNotificationRequested, this, [this](const QString &message, const QVariant &timeout, const QString &actionText, const QJSValue &callBack) {
+                d->rootPlaceHolder->metaObject()->invokeMethod(d->rootPlaceHolder, "showPassiveNotification", Q_ARG(QVariant, message), Q_ARG(QVariant, timeout), Q_ARG(QVariant, actionText), Q_ARG(QVariant, QVariant::fromValue(callBack)));
+            }
+        );
         //New syntax cannot be used to connect to QML types
         connect(d->pageRow, SIGNAL(currentIndexChanged()), this, SLOT(syncCurrentIndex()));
 
